<?php
defined('C5_EXECUTE') or die('Access Denied.');

use Concrete\Core\Support\Facade\Application;
use Concrete\Core\View\View;

/*
 * John Liddiard (aka JohntheFish) www.c5magic.co.uk
 * This software is licensed under the terms described in the concrete5.org marketplace.
 * Please find the add-on there for the latest license copy.
 */
$form = $app->make('helper/form');
$interface = $app->make('helper/concrete/ui');

$selected_info_class = 'elephant-'.trim(preg_replace("/[^0-9a-z]+/i",'_',trim(strtolower($info_cat))),'_');

if (version_compare(Config::get('concrete.version'), '9.0', 'ge')) {
    $header_extra_class = 'elephant-v9-header';
    View::element('v9_header_setup',
                  [
                      // parameters
                      'controller' => $controller,
                      'app'        => $app
                  ],
                  'jl_elephpant_info');
} else {
    $header_extra_class = 'ccm-dashboard-header-buttons';
}
?>
<div class="<?php echo h($header_extra_class); ?> <?php echo h($selected_info_class); ?>">
    <div class="pull-right float-end elephpant_header_menu">
        <form method="post" id="phpinfo_form" action="<?php echo $this->action('view') ?>">
            <button type="button" class="btn btn-primary phpinfo_menu" data-toggle="dropdown" data-bs-toggle="dropdown" aria-haspopup="true" aria-expanded="false"><?php echo t('Menu'); ?> <i
                        class="fa fas fa-bars"></i>
            </button>
            <ul class="dropdown-menu dropdown-menu-end dropdown-menu-right">
                <?php
                foreach ($poss_info_cats as $ky => $val) {
                    if ($ky == 'JTF_SUPPORT') {
                        ?>
                        <li class="info_first_extra">
                            <?php
                            echo $interface->submit($val, $ky, 'left', 'btn-link');
                            ?>
                        </li>
                        <?php
                    } elseif ($ky == $info_cat) {
                        ?>
                        <li class="">
                            <?php
                            echo $interface->submit($val, $ky, 'left', 'btn-link');
                            ?>
                        </li>
                        <?php
                    } else {
                        ?>
                        <li>
                            <?php
                            echo $interface->submit($val, $ky, 'left', 'btn-link');
                            ?>
                        </li>
                        <?php
                    }
                }
                if ($info_cat != 'JTF_SUPPORT') {
                    ?>
                    <li>
                        <?php
                        /*
                         * Needs to be a submit here or we end up with wrong styling!
                         */
                        echo $interface->submit(t('Plain Text'), '#plain_text', 'left', 'btn-link plain-text-toggle', ['title' => t('Toggle to plain text view')]);
                        ?>
                    </li>
                    <li style="display:none;">
                        <?php
                        /*
                         * Needs to be a submit here or we end up with wrong styling!
                         */
                        echo $interface->submit(t('Table View'), '#table_view', 'left', 'btn-link table-view-toggle', ['title' => t('Toggle to table view')]);
                        ?>
                    </li>
                    <?php
                }
                View::element('common_nav', ['controller' => $controller, 'app' => $app], 'jl_elephpant_info');
                ?>
            </ul>
    </div>
    </form>
</div>
<div id="phpinfo_body" class="ccm-pane-body <?php echo h($selected_info_class); ?>">
    <div class="info_as_html">
        <?php
        $os = PHP_OS;
        if ($info_cat !== 'JTF_SUPPORT') {
            ?>
            <div class="alert alert-info">
                <?php
                echo $c->getCollectionDescription();
                ?>
            </div>
            <div class="row">
                <div class="col-sm-6">
                    <h2>
                        <?php
                        echo $poss_info_cats[$info_cat];
                        ?>
                    </h2>
                </div>
                <div class="col-sm-6">
                    <?php
                    View::element('table_filter',
                                  [
                                      // parameters
                                      'controller' => $controller,
                                      'app'        => $app
                                  ],
                                  'jl_elephpant_info');
                    ?>
                </div>
            </div>

            <div>
                <?php
                ob_start();
                phpinfo(constant($info_cat));
                $phpinfoHTML = ob_get_contents();
                ob_end_clean();

                /*
                 * Get the body contents of the phpinfo and do some mashing to make it display
                 * cleanly within a bootstrap page/table
                 */
                if (preg_match("/\<body\>(.*)\<\/body\>/si", $phpinfoHTML, $m)) {
                    $info = $m[1];

                    /*
                     * Allow break after comma. Trick base64 images
                     */
                    $info = preg_replace("/([^4])\,/", '$1,&#8203;', $info);

                    /*
                     *  remove centering from div elements
                     */
                    $info = preg_replace("/\<div class=\"center\"\>/", '<div>', $info);

                    $info = str_replace("<h2>".$poss_info_cats[$info_cat]."</h2>", '', $info);
                    $info = str_replace("<h2>PHP ".$poss_info_cats[$info_cat]."</h2>", '', $info);
                    $info = str_replace("<h1>".$poss_info_cats[$info_cat]."</h1>", '', $info);

                    /*
                     *  add bootstrap styling to table and output to page
                     */
                    echo preg_replace("/\<table/", '<table class="table table-striped table-bordered" ', $info);
                } else {
                    echo t('Unable to find body of phpinfo response. The addon code may need adjusting to work correctly on this server.');
                }
                ?>
            </div>
        <?php
        $select_all = t('Select All');
        $copy_all = t('Select and copy to clipboard');
        ?>
            <script type="text/javascript">
                (function ($) {
                    $(document).ready(function () {
                        var txt_select_all = '<?php echo $select_all; ?>';
                        var txt_copy_all = '<?php echo $copy_all; ?>';

                        /*
                         * First click creates a plain text version. Subsequent clicks
                         * toggle between
                         */
                        $('#phpinfo_form .plain-text-toggle').one('click', function (ev) {
                            ev.preventDefault();
                            var tc = 0;
                            var ops = '';
                            /*
                             * loop into table-row-cell
                             */
                            $('#phpinfo_body table').each(function () {
                                if (tc) {
                                    ops += '\n' + Array(81).join("=") + '\n';
                                }
                                tc++;

                                /*
                                 * any heading before a table
                                 */
                                var poss_h = $(this).prev();
                                if ($(poss_h).is(':header')) {
                                    ops += $(poss_h).text();
                                    ops += '\n' + Array($(poss_h).text().length + 1).join('-') + '\n';
                                }

                                var rows_txt = [];
                                $('#phpinfo_body').find('tr').each(function () {
                                    var cells_txt = [];
                                    $(this).find('td,th').each(function () {
                                        var cell_txt = $(this).text();
                                        if (!cell_txt || cell_txt == 'undefined') {
                                            cell_txt = '';
                                        }
                                        cells_txt.push(cell_txt);
                                    });
                                    rows_txt.push(cells_txt.join('\t'));
                                });
                                ops += rows_txt.join('\n');
                            });

                            /*
                             * Select all is also used for copy all
                             */
                            var selectAll = function () {
                                var info_txt = $('#selectable_text pre');
                                var doc = document;
                                var element = info_txt[0];
                                if (doc.body.createTextRange) {
                                    var range = document.body.createTextRange();
                                    range.moveToElementText(element);
                                    range.select();
                                } else if (window.getSelection) {
                                    var selection = window.getSelection();
                                    var range = document.createRange();
                                    range.selectNodeContents(element);
                                    selection.removeAllRanges();
                                    selection.addRange(range);
                                }
                            };

                            $('#phpinfo_body .info_as_html').hide().after('<div class="info_as_txt ccm-pane-body"><div id="selectable_text"><a id="selectall" href="#selectall">' + txt_select_all + '</a><pre>' + ops + '</pre></div></div>');


                            /*
                             * As simple a way as possible to check if copy works
                             * https://developer.mozilla.org/en-US/docs/Web/API/Document/execCommand
                             */
                            var copyable = false;

                            var can_copy = function () {
                                var succeed;
                                try {
                                    if (!document.execCommand) {
                                        return false;
                                    }
                                    copyable = true;
                                    return true;
                                } catch (e) {
                                    return false;
                                }
                                return false
                            };

                            if (can_copy()) {
                                $('#selectall').text(txt_copy_all);
                            }

                            /*
                             * Copy all
                             * http://stackoverflow.com/questions/22581345/click-button-copy-to-clipboard-using-jquery
                             */
                            $('#selectall').click(function (ev) {
                                ev.preventDefault();
                                ev.stopPropagation();
                                selectAll();
                                if (copyable) {
                                    try {
                                        copyable = document.execCommand('copy');
                                    } catch (err) {
                                        copyable = false;
                                    }
                                }
                                if (!copyable) {
                                    $('#selectall').text(txt_select_all);
                                }
                            });

                            /*
                             * Once the text has been extracted and created, swap to a toggle behaviour
                             */
                            $('#phpinfo_form .phpinfo_menu').trigger('click');
                            $('#phpinfo_form .plain-text-toggle').closest('li').hide();
                            $('#phpinfo_form .table-view-toggle').closest('li').show();
                            $('#phpinfo_form .plain-text-toggle, #phpinfo_form .table-view-toggle').blur().on('click', function (ev) {
                                ev.preventDefault();
                                if ($('#phpinfo_body .info_as_html').is(':visible')) {
                                    $('#phpinfo_body .info_as_html').hide();
                                    $('#phpinfo_body .info_as_txt').show();
                                    $('#phpinfo_form .plain-text-toggle').addClass('active').blur();
                                    $('#phpinfo_form .plain-text-toggle').closest('li').hide();
                                    $('#phpinfo_form .table-view-toggle').closest('li').show();
                                    $('#phpinfo_form .phpinfo_menu').trigger('click');

                                } else {
                                    $('#phpinfo_body .info_as_html').show();
                                    $('#phpinfo_body .info_as_txt').hide();
                                    $('#phpinfo_form .plain-text-toggle').removeClass('active').blur();
                                    $('#phpinfo_form .table-view-toggle').closest('li').hide();
                                    $('#phpinfo_form .plain-text-toggle').closest('li').show();
                                    $('#phpinfo_form .phpinfo_menu').trigger('click');

                                }
                                return false;
                            });

                            return false;
                        });
                    });
                })(jQuery);
            </script>
        <?php
        } else {
        ?>
            <h2>
                <?php echo t('Addon Support'); ?>
            </h2>
            <?php
            View::element('support_dialog',
                //
                          [
                              // parameters
                              'controller'   => $controller,
                              'pkg_handle'   => 'jl_elephpant_info',
                              'c5handle'     => 'ele-php-ant-info',
                              'magic_handle' => 'php_info'
                          ],
                          'jl_elephpant_info');
        }
        ?>
    </div>
</div>


