<?php

namespace JlInfo;
use Illuminate\Support\Arr;

defined('C5_EXECUTE') or die('Access Denied.');


/*
 * Software by John Liddiard (aka JohntheFish)
 * www.c5magic.co.uk
 *
 * This package contains software copyright and proprietary to John Liddiard
 *
 */

class RecursiveTable
{

    /*
     * Run through multiple levels of nested array and format it as a nested table structure.
     * Format elements sensibly. Make JSON look nice.
     */

    public function table($data)
    {
        if (is_array($data)) {
            ?>
            <table class="table table-striped table-condensed table-bordered">
                <tbody>
                <?php
                if(Arr::isAssoc($data)){
                    foreach ($data as $k => $v) {
                        $this->table_row($k, $v);
                    }
                }else {
                    foreach ($data as $k => $v) {
                        if(!empty($v) || $v===false || $v===0){
                            $this->table_simple_row($k,$v);
                        }
                    }
                }
                ?>
                </tbody>
            </table>
            <?php
        }
    }

    public function table_row($k, $v)
    {
        ?>
        <tr>
            <td>
                <?php
                echo h($k);
                ?>
            </td>
            <td>
                <?php
                echo $this->nice_value($v);
                ?>
            </td>
        </tr>
        <?php
    }

    private function table_simple_row($k, $v)
    {
        ?>
        <tr>
            <td>
                <?php
                echo $this->nice_value($v);
                ?>
            </td>
        </tr>
        <?php
    }

    private function nice_value($v){
        if($v === null){
            return 'NULL';
        }else if($v === ''){
            return t('** empty string **');
        }else if($v === false){
            return t('false');
        }else if($v === true){
            return t('true');
        }else if (is_scalar($v)) {
            return $this->nice_scalar($v);
        } elseif (is_array($v)) {
            return $this->nice_table($v);
        } else {
            return $this->nice_whatever($v);
        }
    }

    private function nice_table($v){
        while(!empty($v) && is_array($v) && count($v)===1 && reset(array_keys($v))===0){
            $v = $v[0];
        }
        if(!is_array($v)){
            return $this->nice_value($v);
        }
        return $this->arr_as_formatted_json($v);
    }


    private function nice_scalar($v){
        $v = trim($v);
        $fc = substr($v,0,1);
        $lc = substr($v,-1,1);
        if(empty($fc) || empty($lc)){
            return h($v);
        }
        if($fc!=='[' && $fc!=='{'){
            return h($v);
        }
        if($lc!==']' && $lc!=='}'){
            return h($v);
        }
        /*
         * Could be json
         */
        try{
            $v_arr = json_decode($v, true);
            if(!empty($v_arr) && is_array($v_arr)){
                return $this->arr_as_formatted_json($v_arr);
            }
        }catch(\Exception $e){
           // don't care, not json
        }
        return h($v);
    }

    private function arr_as_formatted_json($v){
        return '<pre>'.h(str_replace("\\\\","\\",json_encode($v,JSON_PRETTY_PRINT + JSON_UNESCAPED_SLASHES))).'</pre>';
    }

    private function nice_whatever($v){
        return gettype($v);
    }
}